==> godot_3.6+ds.orig.tar.xz: godot-3.6-stable/AUTHORS.md <==
# Godot Engine authors

Godot Engine is developed by a community of voluntary contributors who
contribute code, bug reports, documentation, artwork, support, etc.

It is impossible to list them all; nevertheless, this file aims at listing
the developers who contributed significant patches to this MIT licensed
source code. "Significant" is arbitrarily decided, but should be fair :)

GitHub usernames are indicated in parentheses, or as sole entry when no other
name is available.

## Project Founders

    Juan Linietsky (reduz)
    Ariel Manzur (punto-)

## Lead Developer

    Juan Linietsky (reduz)

## Project Manager

    Rémi Verschelde (akien-mga)

## Developers

(in alphabetical order, with over 10 commits excluding merges)

    Aaron Franke (aaronfranke)
    Aaron Record (LightningAA)
    Adam Scott (adamscott)
    Alexander Holland (AlexHolly)
    Alexey Khoroshavin (allkhor)
    Alfred Reinold Baudisch (alfredbaudisch)
    Alket Rexhepi (alketii)
    Andrea Catania (AndreaCatania)
    Andrii Doroshenko (Xrayez)
    Andy Maloney (asmaloney)
    Andy Moss (MillionOstrich)
    Angad Kambli (angad-k)
    Anilforextra (AnilBK)
    Anish Bhobe (KidRigger)
    Anton Yabchinskiy (a12n)
    Anutrix
    Aren Villanueva (kurikaesu)
    Ariel Manzur (punto-)
    AThousandShips
    Bartłomiej T. Listwon (Listwon)
    Bastiaan Olij (BastiaanOlij)
    Ben Brookshire (sheepandshepherd)
    Benjamin Larsson (Nallebeorn)
    Bernhard Liebl (poke1024)
    Bhuvan Vemula (Bhu1-V)
    bitsawer
    Błażej Szczygieł (zaps166)
    Bojidar Marinov (bojidar-bg)
    Brian Semrau (briansemrau)
    Bruno Lourenço (MadEqua)
    Cameron Reikes (creikey)
    Camille Mohr-Daurat (pouleyKetchoupp)
    Caner Demirer (cdemirer)
    Carl Olsson (not-surt)
    Carter Anderson (cart)
    Chris Bradfield (cbscribe)
    Clay John (clayjohn)
    ConteZero
    Dana Olson (adolson)
    Daniel J. Ramirez (djrm)
    Daniel Rakos (aqnuep)
    Daniel Zilberleyb (dzil123)
    Danil Alexeev (dalexeev)
    dankan1890
    David Cambré (Gallilus)
    David Sichma (DavidSichma)
    David Snopek (dsnopek)
    Dharkael (lupoDharkael)
    Dmitry Koteroff (Krakean)
    Dmitry Maganov (vonagam)
    Dominik Jasiński (dreamsComeTrue)
    Douglas Leão (DeeJayLSP)
    DualMatrix
    Ellen Poe (ellenhp)
    Emmanuel Barroga (codecustard)
    Emmanuel Leblond (touilleMan)
    Eoin O'Neill (Eoin-ONeill-Yokai)
    Eric Lasota (elasota)
    Eric M (EricEzaM)
    Eric Rybicki (ericrybick)
    Erik Selecký (rxlecky)
    est31
    Eveline Jarosz (Marqin)
    Fabian Mathews (supagu)
    Fabio Alessandrelli (Faless)
    Fabrice Cipolla (fabriceci)
    Ferenc Arn (tagcup)
    FireForge (fire-forge)
    follower
    foxydevloper
    François Belair (Razoric480)
    Franklin Sobrinho (TheHX)
    Fredia Huya-Kouadio (m4gr3d)
    Geequlim
    George Marques (vnen)
    Gerrit Großkopf (Grosskopf)
    Gilles Roudiere (groud)
    Gordon MacPherson (RevoluPowered)
    Guilherme Felipe de C. G. da Silva (guilhermefelipecgs)
    Hakim Rouatbi (hakro)
    Hanif Bin Ariffin (hbina)
    Haoyu Qiu (timothyqiu)
    Hein-Pieter van Braam-Stewart (hpvb)
    Hendrik Brucker (Geometror)
    hilfazer
    Hiroshi Ogawa (hi-ogawa)
    homer666
    hoontee
    Hugo Locurcio (Calinou)
    Ian Bishop (ianb96)
    Ibrahn Sahir (ibrahn)
    Ignacio Etcheverry (neikeq)
    Igor Kordiukiewicz (IgorKordiukiewicz)
    Ilaria Cislaghi (QbieShay)
    Indah Sylvia (ISylvox)
    J08nY
    Jake Young (Duroxxigar)
    Jakub Grzesik (kubecz3k)
    James Buck (jbuck3)
    Jan Haller (Bromeon)
    Jason Knight (jasonwinterpixel)
    Jean-Michel Bernard (jmb462)
    Jérôme Gully (Nutriz)
    Jia Jun Chai (SkyLucilfer)
    Joan Fons Sanchez (JFonS)
    Johan Manuel (29jm)
    Johannes Witt (HaSa1002)
    Jonathan Nicholl (jtnicholl)
    Jordan Schidlowsky (winterpixelgames)
    Josh Jones (DarkKilauea)
    Joshua Grams (JoshuaGrams)
    Juan Linietsky (reduz)
    Julian Murgia (StraToN)
    Julien Nguyen (Blackiris)
    Jummit
    Justo Delgado (mrcdk)
    karroffel
    Kelly Thomas (KellyThomas)
    kleonc
    Kongfa Waroros (gongpha)
    Kostadin Damyanov (Max-Might)
    K. S. Ernest (iFire) Lee (fire)
    lawnjelly
    Leon Krause (leonkrause)
    Liz Haas (27thLiz)
    Lucien Menassol (Kanabenki)
    Lyuma
    Maganty Rushyendra (mrushyendra)
    Manuele Finocchiaro (m4nu3lf)
    Marcel Admiraal (madmiraal)
    Marcelo Fernandez (marcelofg55)
    Marc Gilleron (Zylann)
    Marcin Zawiejski (dragmz)
    Marcus Brummer (mbrlabs)
    Marcus Elg (MCrafterzz)
    Mariano Javier Suligoy (MarianoGnu)
    Mario Schlack (hurikhan)
    Marios Staikopoulos (marstaik)
    Marius Hanl (Maran23)
    Mark Riedesel (klowner)
    Markus Sauermann (Sauermann)
    Martin Capitanio (capnm)
    Martin Liška (marxin)
    Martin Sjursen (binbitten)
    marynate
    Masoud BH (masoudbh3)
    Mateo Kuruk Miccino (kuruk-mm)
    Matthew (skyace65)
    Matthias Hölzl (hoelzl)
    Max Hilbrunner (mhilbrunner)
    merumelu
    Meru Patel (Janglee123)
    MewPurPur
    Michael Alexsander (YeldhamDev)
    Michał Iwańczuk (iwek7)
    MichiRecRoom (LikeLakers2)
    Micky (Mickeon)
    Mikael Hermansson (mihe)
    MinusKube
    Morris "Tabor" Arroad (mortarroad)
    mrezai
    Muhammad Huri (CakHuri)
    muiroc
    Nathan Franke (nathanfranke)
    Nathan Lovato (NathanLovato)
    Nathan Warden (NathanWarden)
    Nicholas Huelin (SirQuartz)
    Nikita Lita (nikitalita)
    Nils André-Chang (NilsIrl)
    Noah Beard (TwistedTwigleg)
    Nông Văn Tình (nongvantinh)
    Nuno Donato (nunodonato)
    ocean (they/them) (anvilfolk)
    Omar El Sheikh (The-O-King)
    Ovnuniarchos
    Pascal Richter (ShyRed)
    Patrick (firefly2442)
    Paul Batty (Paulb23)
    Paul Joannon (paulloz)
    Paul Trojahn (ptrojahn)
    Pāvels Nadtočajevs (bruvzg)
    Paweł Fertyk (pfertyk)
    Pawel Kowal (pkowal1982)
    Pawel Lampe (Scony)
    Pedro J. Estébanez (RandomShaper)
    Pieter-Jan Briers (PJB3005)
    Poommetee Ketson (Noshyaar)
    Przemysław Gołąb (n-pigeon)
    Rafael M. G. (rafallus)
    Rafał Mikrut (qarmin)
    Ralf Hölzemer (rollenrolm)
    Ramesh Ravone (RameshRavone)
    Raphael2048
    Raul Santos (raulsntos)
    Ray Koopa (RayKoopa)
    RedMser
    RedworkDE
    Rémi Verschelde (akien-mga)
    Rhody Lugo (rraallvv)
    Ricardo Buring (rburing)
    Ricardo Subtil (Ev1lbl0w)
    Riteo Siuga (Riteo)
    Roberto F. Arroyo (robfram)
    Robin Hübner (profan)
    romulox-x
    Rune Smith (rune-scape)
    Ruslan Mustakov (endragor)
    Ryan Roden-Corrent (rrcore)
    Saniko (sanikoyes)
    santouits
    SaracenOne
    Sergey Minakov (naithar)
    sersoong
    Shiqing (kawa-yoiko)
    Silc 'Tokage' Renew (TokageItLab)
    Simon Wenner (swenner)
    smix8
    snailrhymer
    Stijn Hinlopen (hinlopen)
    Swarnim Arun (minraws)
    TC (floppyhammer)
    TechnoPorg
    Thakee Nathees (ThakeeNathees)
    thebestnom
    Theo Hallenius (TheoXD)
    Timo Schwarzer (timoschwarzer)
    Timothé Bonhoure (ajreckof)
    Timo (toger5)
    Tomasz Chabora (KoBeWi)
    trollodel
    Twarit Waikar (IronicallySerious)
    Umang Kalra (theoway)
    Vinzenz Feenstra (vinzenz)
    Vitika Soni (Vitika9)
    박한얼 (volzhs)
    V. Vamsi Krishna (vkbsb)
    Wilhem Barbier (nounoursheureux)
    William Deurwaarder (williamd67)
    Will Nations (willnationsdev)
    Wilson E. Alvarez (Rubonnek)
    Xavier Cho (mysticfall)
    yg2f (SuperUserNameMan)
    Yuri Rubinsky (Chaosus)
    Yuri Sizov (YuriSizov)
    Zae Chao (zaevi)
    Zak Stam (zaksnet)
    Zher Huei Lee (leezh)
    ZuBsPaCe
    风青山 (Rindbee)

==> godot_4.4.1+ds.orig.tar.xz: godot-4.4.1-stable/AUTHORS.md <==
# Godot Engine authors

Godot Engine is developed by a community of voluntary contributors who
contribute code, bug reports, documentation, translations, support, etc.,
across multiple repositories.

It is impossible to list them all; nevertheless, this file aims at listing
the developers who contributed significant improvements to the engine code.

To keep the list curated, we use a threshold of a minimum of 11 commits.

This file does not strictly reflect copyright ownership for the engine
source code. For this, refer to the Git history to know which contributor
wrote which part of the codebase.

GitHub usernames are indicated in parentheses, or as sole entry when no other
name is available.

## Project Founders

    Juan Linietsky (reduz)
    Ariel Manzur (punto-)

## Lead Developer

    Juan Linietsky (reduz)

## Project Manager

    Rémi Verschelde (akien-mga)

## Developers

    Aaron Franke (aaronfranke)
    Aaron Pagano (aaronp64)
    Aaron Record (LightningAA)
    Adam Scott (adamscott)
    Alexander Hartmann (Alex2782)
    Alexander Holland (AlexHolly)
    Alex Drozd (brno32)
    Alexey Khoroshavin (allkhor)
    Allen Pestaluky (allenwp)
    Alfred Reinold Baudisch (alfredbaudisch)
    Alistair Leslie-Hughes (alesliehughes)
    Alket Rexhepi (alketii)
    Alvin Wong (alvinhochun)
    Andrea Catania (AndreaCatania)
    Andreia Gaita (shana)
    Andrés Botero (0xafbf)
    Andrii Doroshenko (Xrayez)
    Andy Maloney (asmaloney)
    Andy Moss (MillionOstrich)
    Angad Kambli (angad-k)
    Anilforextra (AnilBK)
    Anish Bhobe (KidRigger)
    Anish Mishra (syntaxerror247)
    Anni Ryynänen (anniryynanen)
    Anton Yabchinskiy (a12n)
    Anutrix
    Aren Villanueva (kurikaesu)
    Ariel Manzur (punto-)
    arkology
    Arman Elgudzhyan (puchik)
    Arseny Kapoulkine (zeux)
    AThousandShips
    aXu-AP
    Bartłomiej T. Listwon (Listwon)
    Bastiaan Olij (BastiaanOlij)
    Ben Brookshire (sheepandshepherd)
    Benjamin Larsson (Nallebeorn)
    Bernhard Liebl (poke1024)
    Bhuvan Vemula (Bhu1-V)
    bitsawer
    Błażej Szczygieł (zaps166)
    BlueCube3310
    Bojidar Marinov (bojidar-bg)
    Brian Semrau (briansemrau)
    Bruno Lourenço (MadEqua)
    Cameron Reikes (creikey)
    Camille Mohr-Daurat (pouleyKetchoupp)
    Caner Demirer (cdemirer)
    Carl Olsson (not-surt)
    Carter Anderson (cart)
    ChibiDenDen
    Chris Bradfield (cbscribe)
    Chris Cranford (Naros)
    Christian Kaiser (ckaiser)
    Clay John (clayjohn)
    ConteZero
    CookieBadger
    Dana Olson (adolson)
    Daniel J. Ramirez (djrm)
    Daniel Rakos (aqnuep)
    Daniel Zilberleyb (dzil123)
    Danil Alexeev (dalexeev)
    dankan1890
    Darío Banini (DarioSamo)
    David Cambré (Gallilus)
    David Sichma (DavidSichma)
    David Snopek (dsnopek)
    derammo
    Dharkael (lupoDharkael)
    Dirk Steinmetz (rsjtdrjgfuzkfg)
    Dmitry Koteroff (Krakean)
    Dmitry Maganov (vonagam)
    Dominik Jasiński (dreamsComeTrue)
    Douglas Leão (DeeJayLSP)
    DualMatrix
    Ellen Poe (ellenhp)
    Emilio Coppola (coppolaemilio)
    Emmanuel Barroga (codecustard)
    Emmanuel Leblond (touilleMan)
    Eoin O'Neill (Eoin-ONeill-Yokai)
    Eric Lasota (elasota)
    Eric M (EricEzaM)
    Eric Rybicki (ericrybick)
    Erik Selecký (rxlecky)
    est31
    Eveline Jarosz (Marqin)
    Fabian Mathews (supagu)
    Fabio Alessandrelli (Faless)
    Fabrice Cipolla (fabriceci)
    Ferenc Arn (tagcup)
    FireForge (fire-forge)
    Florent Guiocheau (Flarkk)
    Florian Kothmeier (Dragoncraft89)
    follower
    foxydevloper
    François Belair (Razoric480)
    Franklin Sobrinho (TheHX)
    Fredia Huya-Kouadio (m4gr3d)
    Geequlim
    George Marques (vnen)
    Gerrit Großkopf (Grosskopf)
    Giganzo
    Gilles Roudiere (groud)
    Gordon MacPherson (RevoluPowered)
    Guilherme Felipe de C. G. da Silva (guilhermefelipecgs)
    Guillaume Mouton (kiroxas)
    Hakim Rouatbi (hakro)
    Hanif Bin Ariffin (hbina)
    Haoyu Qiu (timothyqiu)
    Hein-Pieter van Braam-Stewart (hpvb)
    Hendrik Brucker (Geometror)
    Hilderin
    Hiroshi Ogawa (hi-ogawa)
    HolonProduction
    homer666
    hoontee
    Hugo Locurcio (Calinou)
    Ian Bishop (ianb96)
    Ibrahn Sahir (ibrahn)
    Ignacio Roldán Etcheverry (neikeq)
    Igor Kordiukiewicz (IgorKordiukiewicz)
    Ilaria Cislaghi (QbieShay)
    Indah Sylvia (ISylvox)
    Ivan Šachov (van800)
    J08nY
    Jake Young (Duroxxigar)
    Jakub Grzesik (kubecz3k)
    Jakub Marcowski (Chubercik)
    James Buck (jbuck3)
    Jan Haller (Bromeon)
    Jason Knight (jasonwinterpixel)
    Jean-Michel Bernard (jmb462)
    Jérôme Gully (Nutriz)
    Jia Jun Chai (SkyLucilfer)
    jitspoe
    Joan Fons Sanchez (JFonS)
    Johan Aires Rastén (JohanAR)
    Johan Manuel (29jm)
    Johannes Witt (HaSa1002)
    Jonathan Nicholl (jtnicholl)
    Jordan Schidlowsky (winterpixelgames)
    Josh Jones (DarkKilauea)
    Joshua Grams (JoshuaGrams)
    Juan Linietsky (reduz)
    Julian Murgia (StraToN)
    Julien Nguyen (Blackiris)
    Jummit
    Justo Delgado (mrcdk)
    karroffel
    Kassandra Pucher (PucklaJ)
    Kelly Thomas (KellyThomas)
    kleonc
    Kongfa Waroros (gongpha)
    Kostadin Damyanov (Max-Might)
    K. S. Ernest (iFire) Lee (fire)
    Kyle Eichlin (likeich)
    Lars Pettersson (larspet)
    lawnjelly
    Leon Krause (leonkrause)
    Liz Haas (27thLiz)
    Logan Lang (devloglogan)
    Lucien Menassol (Kanabenki)
    Lukas Tenbrink (Ivorforce)
    Lyuma
    Maganty Rushyendra (mrushyendra)
    Magian (magian1127)
    Mai Lavelle (maiself)
    Malcolm Anderson (Meorge)
    Malcolm Nixon (Malcolmnixon)
    Manuele Finocchiaro (m4nu3lf)
    Marcel Admiraal (madmiraal)
    Marcelo Fernandez (marcelofg55)
    Marc Gilleron (Zylann)
    Marcin Zawiejski (dragmz)
    Marcus Brummer (mbrlabs)
    Marcus Elg (MCrafterzz)
    Mariano Javier Suligoy (MarianoGnu)
    Mario Liebisch (MarioLiebisch)
    Mario Schlack (hurikhan)
    Marios Staikopoulos (marstaik)
    Marius Hanl (Maran23)
    Mark DiBarry (markdibarry)
    Mark Riedesel (klowner)
    Markus Sauermann (Sauermann)
    Martin Capitanio (capnm)
    Martin Liška (marxin)
    Martin Sjursen (binbitten)
    marynate
    Masoud BH (masoudbh3)
    Mateo Kuruk Miccino (kuruk-mm)
    Matias N. Goldberg (darksylinc)
    Matthew Murphy (mashumafi)
    Matthew (skyace65)
    Matthias Hölzl (hoelzl)
    Max Hilbrunner (mhilbrunner)
    merumelu
    Meru Patel (Janglee123)
    MewPurPur
    Michael Alexsander (YeldhamDev)
    Michał Iwańczuk (iwek7)
    MichiRecRoom (LikeLakers2)
    Micky (Mickeon)
    Mikael Hermansson (mihe)
    Mika Viskari (miv391)
    MinusKube
    MJacred
    Mounir Tohami (WhalesState)
    mrezai
    Muhammad Huri (CakHuri)
    muiroc
    myaaaaaaaaa
    Nathalie Galla (MurderVeggie)
    Nathan Franke (nathanfranke)
    Nathan Lovato (NathanLovato)
    Nathan Warden (NathanWarden)
    Nazarii Yablonskyi (Nazarwadim)
    Nicholas Huelin (SirQuartz)
    Nikita Lita (nikitalita)
    Nils André-Chang (NilsIrl)
    Noah Beard (TwistedTwigleg)
    Nông Văn Tình (nongvantinh)
    Nuno Donato (nunodonato)
    ocean (they/them) (anvilfolk)
    Omar El Sheikh (The-O-King)
    Ovnuniarchos
    Pablo Andres Fuente (pafuent)
    Pascal Richter (ShyRed)
    passivestar
    Patrick Dawson (pkdawson)
    Patrick Exner (FlameLizard)
    Patrick (firefly2442)
    patwork
    Paul Batty (Paulb23)
    Paul Joannon (paulloz)
    Paul Trojahn (ptrojahn)
    Pāvels Nadtočajevs (bruvzg)
    Paweł Fertyk (pfertyk)
    Pawel Kowal (pkowal1982)
    Pawel Lampe (Scony)
    Pedro J. Estébanez (RandomShaper)
    Pieter-Jan Briers (PJB3005)
    Poommetee Ketson (Noshyaar)
    Przemysław Gołąb (n-pigeon)
    Radiant (radiantgurl)
    Rafael M. G. (rafallus)
    Rafał Mikrut (qarmin)
    Raffaele Picca (RPicster)
    Ralf Hölzemer (rollenrolm)
    Ramesh Ravone (RameshRavone)
    Raphael2048
    Raul Santos (raulsntos)
    Ray Koopa (RayKoopa)
    RedMser
    RedworkDE
    Rémi Verschelde (akien-mga)
    Rhody Lugo (rraallvv)
    Ricardo Buring (rburing)
    Ricardo Subtil (Ev1lbl0w)
    Riteo Siuga (Riteo)
    Roberto F. Arroyo (robfram)
    Robert Yevdokimov (ryevdokimov)
    Robin Hübner (profan)
    romulox-x
    Rudolph Bester (Rudolph-B)
    Rune Smith (rune-scape)
    Ruslan Mustakov (endragor)
    Ryan Roden-Corrent (rrcore)
    Saniko (sanikoyes)
    santouits
    SaracenOne
    Septian Ganendra S. K. (sepTN)
    Sergey Minakov (naithar)
    sersoong
    Shiqing (kawa-yoiko)
    Silc 'Tokage' Renew (TokageItLab)
    Simon Wenner (swenner)
    smix8
    snailrhymer
    Sofox (TheSofox)
    Stanislav Labzyuk (DarkMessiah)
    Stijn Hinlopen (hinlopen)
    stmSi
    Stuart Carnie (stuartcarnie)
    Swarnim Arun (minraws)
    TC (floppyhammer)
    TechnoPorg
    tetrapod00
    Thaddeus Crews (Repiteo)
    Thakee Nathees (ThakeeNathees)
    thebestnom
    Theo Hallenius (TheoXD)
    Thomas ten Cate (ttencate)
    Timo Schwarzer (timoschwarzer)
    Timothé Bonhoure (ajreckof)
    Timo (toger5)
    Tomasz Chabora (KoBeWi)
    Travis Lange (TCROC)
    trollodel
    Twarit Waikar (IronicallySerious)
    Umang Kalra (theoway)
    Victor Hampel (havi05)
    Vinzenz Feenstra (vinzenz)
    Vitika Soni (Vitika9)
    박한얼 (volzhs)
    V. Vamsi Krishna (vkbsb)
    Wilhem Barbier (nounoursheureux)
    William Deurwaarder (williamd67)
    Will Nations (willnationsdev)
    Wilson E. Alvarez (Rubonnek)
    Xavier Cho (mysticfall)
    Yaohua Xiong (xiongyaohua)
    Yevhen Babiichuk (dustdfg)
    yg2f (SuperUserNameMan)
    Yordan Dolchinkov (Jordyfel)
    Yufeng Ying (YYF233333)
    Yuri Rubinsky (Chaosus)
    Yuri Sizov (YuriSizov)
    Zae Chao (zaevi)
    Zak Stam (zaksnet)
    Zher Huei Lee (leezh)
    Zi Ye (MajorMcDoom)
    ZuBsPaCe
    Дмитрий Сальников (DmitriySalnikov)
    忘忧の (Daylily-Zeleen)
    谢天 (jsjtxietian)
    风青山 (Rindbee)
